@@ -10,13 +10,10 @@ our %Remote = (
         male   => 'http://en.wikipedia.org/wiki/List_of_male_porn_stars'
     },
     extract => sub {
-        return 
-            map { Acme::MetaSyntactic::RemoteList::tr_accent($_) }
-            map { Acme::MetaSyntactic::RemoteList::tr_utf8_basic($_) }
-            grep { ! /^List_|_Groups$/ }
+        return map { Acme::MetaSyntactic::RemoteList::tr_utf8_basic($_) }
             map { s/[-\s']/_/g; s/[."]//g; $_ }
             $_[0]
-            =~ m{^<li>(?:<[^>]*>)?(.*?)(?:(?: ?[-,(<]| aka | see ).*)?</li>}mig
+            =~ m{^<li><(?:a href|i)[^>]*>((?!List of)[^<]*?)(?:(?:,| \()[^<].*)?</[ai]>.*?</li>}mig
     },
     ,
 );
@@ -43,26 +40,6 @@ Sbastien Aperghis-Tramoni.
 
 Introduced in version 0.69, published on April 10, 2006.
 
-Updates from Wikipedia:
-
-=over 4
-
-=item version 0.70, published on April 17, 2006
-
-=item version 0.71, published on April 24, 2006
-
-=item version 0.72, published on May 1, 2006
-
-=item version 0.74, published on May 15, 2006
-
-=item version 0.75, published on May 22, 2006
-
-=item version 0.79, published on June 19, 2006
-
-=item version 0.89, published on August 28, 2006
-
-=back
-
 =head1 SEE ALSO
 
 L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::MultiList>.
@@ -71,41 +48,33 @@ L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::MultiList>.
 
 __DATA__
 # names female
-Abigail_Clayton
 Adara_Michaels
-Addison_Rose
 Adele_Stevens
 Adriana_Sage
-Adrienne_Bellaire
-Africa_Sexxx
+Africa_Sexx
 Ai_Iijima
 Aimee_Sweet
 Aja
 Akira_Fubuki
 Alana_Evans
 Alaura_Eden
-Alex_Dane
 Alex_Jordan
 Alex_Taylor
 Alexa_May
 Alexa_Rae
-Alexa_Weix
 Alexandra_Nice
 Alexandra_Silk
 Alexis_Amore
-Alexis_DeVell
 Alexis_Malone
-Alexis_May
-Alicia_Alighatti
+Alexis_DeVell
 Alicia_Monet
 Alicia_Rhodes
 Alicia_Rio
 Alisha_Klass
 Alison_Angel
-Aliyah_Yi
-Allie
+Aliyah_Likit
 Allie_Sin
-Allison_Wyte
+Allison_Whyte
 Ally_Mac_Tyana
 Allysin_Chaynes
 Amber_Lynn
@@ -119,50 +88,39 @@ Andrea_Butjko
 Andrea_True
 Aneta_Smrhova
 Angel_Dark
-Angel_Kelly
 Angel_Long
+Angel_Kelly
 Angela_Baron
 Angela_Devi
-Angela_Haze
-Angela_Tiger
 Angelica_Bella
 Angelica_Costello
 Angelica_Sin
-Angelina_Crow
 Anika_Fox
 Anita_Blond
-Anita_Dark
 Anja_Juliette_Laval
 Anjali_Kara
-Ann_Marie
 Anna_Malle
 Anna_Marek
 Anna_Nova
 Anna_Ohura
-Anna_Ventura
 Annabel_Chong
 Anne_Howe
 Annette_Haven
-Annie_Cruz
 Annie_Sprinkle
 Annie_Swanson
-April_Summers
 Arcadia_Lake
 Aria_Giovanni
 Ariana_Jollee
-Arsen_Wenger
 Ashley_Blue
 Ashley_Long
 Ashlyn_Gere
 Ashton_Moore
 Asia_Carrera
-Aspen_Stevens
 Asuka_Sakamaki
+Aspen_Stevens
 Audrey_Hollander
 Aurora_Snow
-Austin_Kincaid
 Austin_O_Riley
-Autumn_Jade
 Ava_Devine
 Ava_Nova
 Ava_Ramone
@@ -177,55 +135,40 @@ Bambi_Blaze
 Bambi_Woods
 Bamboo
 Barbara_Dare
-Barbara_Summer
 Barbie_Griffin
 Belladonna
 Betty_G
 Beverley_Cocks
 Beverly_Lynne
 Bianca_Biaggi
-Bianca_Pureheart
 Bianca_Trump
 Bibi_Fox
+Bianca_Pureheart
 Bionca
-Black_Diamond
-Black_Widow
-Blair_Segal
 Blondie_Bee
 Bobbi_Billard
 Bobbi_Eden
 Bodil_Joensen
 Bonita_Saint
 Boo_D_Licious
-Brandi_Love
 Brandi_Lyons
-Brandi_Wine
 Brandy_Alexandre
 Brandy_Bosworth
-Brandy_Starz
-Brandy_Talore
 Breanne
 Briana_Banks
 Brianna_Rai
 Bridget_the_Midget_Powerz
-Bridgette_Belle
 Bridgette_Kerkove
-Bridgette_Monet
-Bridgette_Monroe
 Brigitte_Lahaie
-Britney_Rears
-Brittany_Andrews
 Brittany_Blue
 Brittany_Stryker
 Brittney_Skye
+Brooke
 Brooke_Ashley
-Brooke_Biggs
-Brooke_Milano
 Brooke_West
-Buffy_Davis
 Bunko_Kanazawa
-Bunny_Bleu
 Bunny_Luv
+Bunny_Bleu
 Cailey_Taylor
 Calli_Cox
 Cameron_Cain
@@ -243,92 +186,67 @@ Carmen_Hayes
 Carmen_Luvana
 Carol_Connors
 Carol_Cummings
-Caroline_Pierce
 Casey_James
 Cassandra_Wild
 Catalina_Cruz
 Celeste
 Celia_Blanco
-Champagne
 Charlene_Aspen
 Charlie_Angel
 Charlie
-Charlie_Style
-Charlotte_Stokely
-Charmaine_Sinclair
 Charmane_Star
 Chasey_Lain
 Chaz
 Chelsea_Charms
-Cheri_Lai
 Cherie
-Cherokee
-Cherry_Lee
 Cherry_Poppens
 Cherry_Potter
 Cherry_Rain
-Cherry_Rose
 Chessie_Moore
 Cheyenne_Silver
 Chloe
 Chloe_Dior
-Chloe_Foxxx
 Chloe_Jones
 Chloe_Vevrier
 Chocolate
 Chris_Cassidy
 Christi_Lake
-Christie_Lee
-Christina_Noir
-Christine_Allure
 Christine_Young
 Christy_Canyon
 Cicciolina
 Ciera_Sage
 Cindy_Crawford
-Cindy_Miel
 Clara_Morgane
 Claudia_Ferrari
 Claudia_Jamsson
-Claudia_Rossi
 Claudine_Beccarie
-Colette_Choisez
 Constance_Money
 Corina_Taylor
-Cris_Cassidy
 Cris_Taliana
 Crissy_Cums
 Crissy_Moran
 Cristina_Bella
 Crystal_Breeze
-Crystal_Craft
-Crystal_Holland
 Crystal_Klein
 Crystal_Knight
 Crystal_Ray
 Crystal_Steal
-Cynara_Fox
-Cyndee_Summers
 Cytherea
-Daisy_Marie
 Dana_Dylan
 Dana_Lynn
 Dana_Vespoli
 Dani_Woodward
-Daniella_Rush
 Danni_Ashe
 Daphne_Rosen
 Darla_Crane
+Dasani_Lezian
 Dasha
 Debi_Diamond
 Deborah_Wells
 Deidre_Holland
-Demi_Marx
-Denise_Masino
-Desire_Vinci
+Desirae
 Desiree_Cousteau
 Desiree_West
-Destiny_Deville
 Destiny_Summers
 Deven_Davis
 Devin_DeRay
@@ -338,6 +256,7 @@ Devon_Michaels
 Diana_Devoe
 Dina_Jewel
 Dolly_Buster
+Dominique_Dewitt
 Dominique_Simone
 Donita_Dunes
 Dora_Venter
@@ -346,23 +265,16 @@ Draghixa
 Dru_Berrymore
 Dyanna_Lauren
 Ebony_Ayes
-Eden_Alaura
-Elizabeth_Del_Mar
-Elizabeth_Lawrence
 Emma_Nixon
 Emma_Starr
-Erica_Bella
 Erica_Boyer
 Erica_Campbell
 Estelle_Desanges
 Eva_Angelina
-Eva_Black
 Eva_Henger
 Eve_Angel
-Eve_Laurence
-Evelyn_Janaei
+Eve_Lawrence
 Fallon
-Fallon_Sommers
 Felecia
 Felecia_Fox
 Felicia_Tang
@@ -370,52 +282,39 @@ Felix_Vicious
 Flame
 Flick_Shagwell
 Flower_Tucci
-Fovea
-Foxy_Lady
-Friday
 Fujiko_Kano
-Gail_Lawrence
 Gauge
-Gen_Padova
 Genevieve_Elise_Silva
 Georgette_Neale
 Georgina_Lempin
 Georgina_Spelvin
-Ghost_Angel
+Gen_Padova
 Gia_Jordan
 Gia_Paloma
 Gianna_Michaels
 Gina_Carrera
 Gina_Lynn
 Gina_Ryder
-Gina_Wild
 Ginger_Lynn
 Gloria_Guida
 Gloria_Leonard
-Greta_Milos
-Gwen_Summers
-Haley_Paige
 Hannah_Harper
 Haven
-Heather_Harmon
 Heather_Hunter
 Helga_Sven
 Hillary_Scott
 Holly_Body
-Holly_McCall
 Holly_Page
-Holly_Wellin
+Haley_Paige
 Honey_Wilder
 Houston
 Hyapatia_Lee
-Ice_La_Fox
 Inari_Vachs
 India
-Isabella_Camille
-Isabella_Soprano
 Isis_Nile
 JR_Carrington
 Jackie_Ashe
+Jackie_Hincapie
 Jackie_Moore
 Jacqueline_Lorians
 Jada_Fire
@@ -426,7 +325,6 @@ Jaimee_Foxworth
 Jamie_Brooks
 Jamie_Summers
 Jana_Cova
-Jana_Miartusova
 Jane_Darling
 Janet_Jacme
 Janette_Littledove
@@ -434,22 +332,16 @@ Janey_Robbins
 Janine_Lindemulder
 Jasmin_St_Claire
 Jasmine_Byrne
+Jasmine_Kerry
 Jasmine_Lynn
-Jasmine_Tame
 Jassie_James
-Jaye_Starr
 Jayna_Oso
-Jazmin
 Jeanna_Fine
 Jelena_Jensen
-Jenaveve_Jolie
 Jenna_Haze
 Jenna_Jameson
-Jennifer_Andersson
-Jennifer_Luv
 Jennifer_Noxt
 Jenteal
-Jesse_Capelli
 Jesse_Jane
 Jessica_Darlin
 Jessica_Dee
@@ -458,64 +350,53 @@ Jessie_St_James
 Jewel_De_Nyle
 Jezebelle_Bond
 Jill_Kelly
-Joanna_Angel
 Joanne_Jo_Guest
-Jodie_Moore
-Joelean
-Johnni_Black
+Johnnie_Black
 Jordan_Capri
-Jordan_Haze
 Jordan_Lee
-Joselyn_Pink
-Joy_Kiss
+Jody_Moore
+Jordan_Haze
 Judy_Star
-Juli_Ashton
 Julia_Ann
 Julia_Bond
+Juli_Ashton
+Julie_Night
 Julia_Channel
 Julia_Parton
 Julie_Meadows
-Julie_Night
-Julie_Silver
 Julie_Strain
 Juliet_Anderson
 Justine_Joli
 Kacey
-Kaitlyn_Ashley
-Kandi_Barbour
-Karen_Dior
+Kate_Frost
 Karen_Lancaume
-Karen_Summers
 Karin_Schubert
 Karina_Kay
+Katie_Fey
+Keiko_Nakazawa
+Kaitlyn_Ashley
+Karen_Dior
 Kascha_Papillon
 Katalyn_Cica
-Kate_Frost
-Katerina_Konec
 Kathy_Willets
 Katie_Gold
 Katie_Morgan
-Katja_Kassin
 Katja_Kean
-Katja_Love
-Katrina_Kraven
+Katja_Kassin
 Katsumi
 Kawashima_Azumi
 Kay_Parker
-Kayla_Marie
 Kaylani_Lei
 Kaylynn
-Keiko_Nakazawa
-Keisha
 Kelle_Marie
-Kelly_Erikson
 Kelly_Kline
 Kelly_Kroft
 Kelly_Nichols
 Kelly_O_Dell
+Kelly_Stafford
 Kelly_Trump
 Kelly_Wells
-Kelsey_Michaels
+Keisha
 Keri_Sable
 Kerry_Marie
 Kianna_Dior
@@ -523,20 +404,15 @@ Kikki_Daire
 Kiko_Wu
 Kim_Angeli
 Kim_Chambers
-Kim_Eternity
-Kimberly_Carson
+Kinky_Celine
 Kinzie_Kenner
-Kira_Kener
-Kitten_Natividad
 Kitty_Marie
 Kitty_Yung
 Kobe_Tai
-Krista_Lane
 Kristara_Barrington
-Kristi_Myst
-Krystal_de_Boor
-Krystal_Steal
 Krysti_Lynn
+Kristi_Myst
+Krystal_Steal
 Kyla_Cole
 Kylie_Ireland
 Lacey_Duvalle
@@ -545,102 +421,75 @@ Lara_Roxx
 Laura_Angel
 Laura_Gemser
 Laure_Sainclair
+Lauren_Hays
 Lauren_Phoenix
 Layla_Jade
+Leanni_Lei
 Lea_De_Mae
-Lea_Walker
 Leanna_Foxxx
 Leanna_Heart
-Leanni_Lei
 Leena
 Lene_Hefner
 Leslie_Bovee
-Letha_Weapons
-Lexie_Marie
-Lexus_Locklear
-Lillian_Tiger
 Lily_Thai
+Lillian_Tiger
 Linda_Lovelace
 Linda_Lust
 Linda_Thoren
 Linda_Wong
 Linsey_Dawn_McKenzie
-Lisa_Ann
 Lisa_De_Leeuw
-Lisa_K_Loring
+Lisa_Ann
+Lisa_Loring
 Lisa_Sparxxx
 Little_Oral_Annie
-Liz_Harvey
-Liz_Honey
-Liz_Vicious
 Liza_Harper
 Logan_LaBrent
 Lois_Ayres
 Lolo_Ferrari
 Loni_Sanders
-Lorelei
-Loretta_Loren
 Lori_Alexia
-Lou_Valmont
-Lovette
-Lucie_Stratilova
 Lucy_Lee
 Lucy_Thai
 Luna_Lane
 Lyla_Lei
-Lynda_Leigh
-Madison_Stone
-Makayla_Coxxx
-Mai_Lee
 Mai_Lin
 Maia_Ginger
-Mandi_Wine
+Madison_Stone
 Mandy_Bright
-Maria_Tortuga
 Mariah_Kekkonen
 Marilyn_Chambers
-Marketa_Brymova
-Mary_Anne
 Mary_Carey
 Mary_Millington
 Marylin_Star
 Maya_Gold
 McKayla_Matthews
-McKenzie_Lee
-Megan_Jones
 Megan_Leigh
-Megan_Martinez
 Melanie_Jagger
 Melissa_Ashley
-Melissa_Harrington
 Melissa_Hill
 Melissa_Lauren
 Melissa_Milano
 Melissa_Walker
 Melody_Love
 Melody_Max
-Mercedesaka_Eva_Black
 Mercedez
 Mia_Smiles
 Michaela_Schaffrath
 Michele_Evette_Watley
-Michelle_Barrett
 Michelle_Monaghan
 Michelle_Thorne
 Michelle_Wild
 Micka_French
-Midori
 Mika_Tan
 Miko_Lee
 Mimi_Miyagi
-Mindy_Rae
 Mindy_Vega
 Minka
 Miriam_Gonzalez
 Miss_Arroyo
 Missy
 Missy_Monroe
-Mistress_Yvette
 Misty_Rain
 Moana_Pozzi
 Mocha
@@ -651,41 +500,30 @@ Monica_Sweet
 Monica_Sweetheart
 Monique_Alexander
 Monique_DeMoan
-Mya_Mason
-Mysti_May
 Nadia_Nyce
 Naomi
-Natasha_Yi
-Naughty_Allie
-Naughty_Alysha
 Nautica_Thorn
+Naughty_Alysha
 Nena_Cherry
 Nichola_Holt
 Nici_Sterling
-Nicki_Hunter
-Nicole_Lace
-Nicole_Sheridan
 Nikita_Denise
 Nikki_Anderson
 Nikki_Benz
+Nikky_Blond
 Nikki_Carlisle
 Nikki_Charm
 Nikki_Dial
-Nikki_Diamond
-Nikki_Fairchild
 Nikki_Fritz
 Nikki_Hunter
 Nikki_Knights
 Nikki_Nova
 Nikki_Park
-Nikki_Rider
 Nikki_Tyler
-Nikky_Blond
 Nina_DePonca
 Nina_Hartley
-Nina_Mercedez
 Nyomi_Marcela
-O
+O_Pearl
 Obsession
 Olinka_Ferova
 Olivia_Del_Rio
@@ -693,22 +531,17 @@ Olivia_O_Lovely
 Olivia_Saint
 Ona_Zee
 Ovidie
-PJ_Sparxx
-Paizley_Adams
+Pamela_Anderson
+Pandora_Dreams
 Pandora_Peaks
-Paris_Showers
-Pason
-Patti_Petite
 Penelope_Black_Diamond
 Penny_Flame
 Penny_Porsche
 Persia
-Phyllisha_Anne
-Phoenix_Ray
 Pixie
+PJ_Sparxx
 Poppy_Morgan
 Porsche_Lynn
-Porsha_Blaze
 Rachel_Aziani
 Rachel_Rotten
 Rachel_Ryan
@@ -720,27 +553,16 @@ Raylene
 Rayveness
 Rebecca_Cummings
 Rebecca_Lord
-Rebecca_Wild
-Red_Heaven
 Reika
-Rene_Bond
-Rene_Tiffany
-Renee_LaRue
 Renee_Pornero
-Rikki_Anderson
-Riley_Mason
 Rita_Faltoyano
 Rocki_Roads
-Ronni_Tuscadero
 Roxanne_Hall
-Roxetta
 Roxy_Jezel
 Roxy_Rush
-Sabina_Black
 Sabrina_Johnson
 Sabrine_Maui
 Sakura_Sena
-Samantha_Fox
 Samantha_Sterlyng
 Samantha_Strong
 Sandee_Westgate
@@ -749,16 +571,13 @@ Sandra_Shine
 Sandy
 Saphire_Rae
 Sara_Jay
-Sarah_Blue
 Sarah_Louise_Young
-Sarah_Twain
 Sativa_Rose
 Savanna_Samson
 Savannah
 Seka
 Selen
 Selena_Silver
-Selena_Steele
 Serena
 Serenity
 Shakina_Shergold
@@ -766,38 +585,40 @@ Shanna_McCullough
 Sharka_Blue
 Sharon_Kane
 Sharon_Mitchell
+Shasta
 Shauna_Grant
 Shay_Sweet
 Shayla_LaVeaux
-Shyla_Foxxx
+Shelby_Belle
 Shyla_Stylez
 Sierra
 Silvia_Saint
+Silvie_Thomas
 Simone
 Simony_Diamond
 Sindee_Coxx
-Sinderella
+Sin_Eye
 Sky_Lopez
 Sophia_Ferrari
 Sophia_Rossi
-Sophie_Deei
 Sophie_Evans
 Sophie_Moone
 Spring_Thomas
 Stacey_Donovan
 Stacy_Burke
+Stacy_Silver
 Stacy_Valentine
 Stephanie_Bellars
 Stephanie_Swift
 Stormy
 Summer_Cummings
 Sunny_Leone
-Sunny_Rain
 Sunrise_Adams
-Sunset_Thomas
 Sunshine_Nee
+Sunset_Thomas
 Susan_Nero
-Suzie_Carina
+Suzi_Suzuki
+Sweet_Amy_Lee
 Sydney_Moon
 T_J_Hart
 Tabatha_Cash
@@ -806,91 +627,74 @@ Tabitha_Stevens
 Taija_Rae
 Tammi_Ann
 Tania_Russof
+Tianna
 Tanya_Hansen
-Tanya_James
 Tawnee_Stone
 Tawny_Roberts
-Tawny_Pearl
 Taylor_Hayes
 Taylor_Hill
-Taylor_Lyn
+Taylor_Lynn
 Taylor_Rain
 Taylor_St_Clair
 Taylor_Wane
 Teagan_Presley
 Teanna_Kai
-Teena_Fine
 Temptress
 Tera_Heart
 Tera_Patrick
 Teresa_May
-Teresa_Scott
 Teri_Diver
 Teri_Weigel
 Terri_Summers
 Texas_Presley
 Tia_Bella
-Tia_Tanaka
-Tianna
 Tianna_Lynn
-Tiffany_Diamond
 Tiffany_Holiday
 Tiffany_Hopkins
 Tiffany_May
 Tiffany_Million
 Tiffany_Mynx
-Tiffany_Rayne
-Tiffany_Rose
 Tiffany_Teen
 Tiffany_Towers
 Tiffany_Walker
 Timea_Vagvolgyi
-Tina_Cheri
-Tina_Fine
+Tove_Jensen
 Tori_DeLuca
 Tori_Welles
 Tory_Lane
-Tove_Jensen
 Tracey_Adams
 Traci_Lords
 Tricia_Devereaux
 Trinity_Loren
 Trixie_Teen
-Tyffany_Million
 Tyla_Wynn
 Tyler_Faith
 Uschi_Digard
-Valentina_Vaughn
 Vanessa_Blue
-Vanessa_Chase
 Vanessa_Del_Rio
 Vanessa_Lane
-Vanessa_McKenzie
 Velicity_Von
 Velvet_Rose
 Venus
-Veronica_Carso
 Veronica_Hart
-Veronica_Moser
+Veronica_Stark
 Veronika_Raquel
-Veronika_Simon
 Veronika_Zemanova
 Vicky_Vette
 Victoria_Givens
 Victoria_Knight
-Victoria_Paris
-Victoria_Sweet
 Victoria_Zdrok
+Victoria_Sweet
 Vida_Garman
 Violet_Blue
 Watase_Akira
-Wendy_Jaymes
-Wendy_Whoppers
 Wifey
+Wanda_Curtis
+Wendy_Whoppers
 Yana_Cova
 Yulia_Nova
-Yvette_Wilde
 Zara_Whites
+Zarina
 Zdenka
 Zsanett_Egerhazi
 # names male
@@ -900,23 +704,18 @@ Alain_Deloin
 Alberto_Rey
 Alec_Metro
 Ales_Hanak
+Alex_Fawkes
 Alex_Rox
-Alex_Sanders
 Alexander_Devoe
 Alexandre_Frota
-Andre_Chazel
-Andrea_Nobili
-Barrett_Blade
 Barry_Wood
 Ben_Dover
 Ben_English
-Ben_Hardy
 Benjamin_Brat
 Big_Herc
 Biggz
 Biff_Malibu
 Billy_Banks
-Billy_Dee
 Billy_Glide
 Bobby_Blake
 Bobby_Vitale
@@ -933,21 +732,19 @@ Bruno_Sx
 Brutus_Black
 Buck_Adams
 Byron_Long
+Brian_Michael_Kuczynski
 Cal_Jammer
 Captain_Bob
 Carlos_Krystal
-Carmelo_Petix
 Chance_Ryder
 Cheyne_Collins
 Chris_Cannon
 Chris_Charming
 Chris_Evans
-Chris_small_package_Marshman
 Christoph_Clark
 Claudio_Meloni
 Colt_Steele
 Dale_DaBone
-Daniel_Espinoza
 Daniel_Kane
 Daniel_Thuerrigl
 Darren_James
@@ -957,7 +754,6 @@ David_Christopher
 David_Cahse
 David_Perry
 David_Ruby
-Deep_Threat
 Devlin_Weed
 Dez
 Dick_Dashton
@@ -969,26 +765,19 @@ Dino_Bravo
 Dino_Toscani
 Don_Fernando
 Don_Hollywood
-Donny_Long
 Ed_Powers
-Ed_Luistro
-Eduardo_Yanez
 Elone_Disere
 Eric_Manchester
 Eric_Masterson
 Eric_Price
 Erik_Everhard
-Etienne_Jaumillot
 Evan_Stone
-Frankie_Jay
 Falcon_X
 Ficky_Martin
 FM_Bradley
 Francesco_Malcom
 Franco_Roccaforte
-Franco_Trentalance
 Francois_Papillon
-Frank_Gun
 Frank_Major
 Frank_Shaft
 Frank_Towers
@@ -996,15 +785,11 @@ Frankie_Versace
 Gene_Ross
 George_Payne
 George_Uhl
-Gerard_Luig
 Gigantua
-Gilbert_Servien
 Gino_Greco
 Greg_Rome
 Greg_Centauro
-Guy_Bonnafoux
 Guy_DaSilva
-Guy_Masse
 Hank_Rose
 Harry_Reems
 Henry_Pachard
@@ -1012,7 +797,6 @@ Herschel_Savage
 HPG
 Ian_Daniels
 Ian_Scott
-Iron_Lee
 Jack_Baker
 Jack_Bravo
 Jack_Hammer
@@ -1025,28 +809,24 @@ Jake_Steed
 James_Bonn
 James_Brossman
 Jamie_Gillis
-Jan_Olav_Norberg
+Jan_Olav_Norberg_aka_Stumpen
 Jason_Zupalo
 Jasper_Wade
 Jay_Ashley
 Jay_Crew
-Jean
+Jean_Claude_Batiste
 Jean_Pierre_Armand
 Jean_Louis
-Jean_Roche
 Jean_Yves_LeCastel
 Jeff_Stryker
 Jeremy_Tucker
 Jerry_Butler
-J_J_Michaels
 Joachim_Kessef
 Joel_Lawrence
 Joey_Ray
-Joey_Hafley
 Joey_Silvera
 John_Dough
 John_Holmes
-John_Leslie
 Johnny_Nineteen
 John_Slovak
 John_Stagliano
@@ -1057,7 +837,6 @@ Jonathan_Stern
 Jon_Dough
 Johnny_Depth
 Jolth_Walton
-Jules_Jordan
 Julian
 Juliano_Ferraz
 Julian_St_Jox
@@ -1084,33 +863,32 @@ Mario_Rossi
 Mark_Anthony
 Mark_Ashley
 Mark_Davis
-Mark_Sloan
 Mark_Wood
 Marty_Romano
 Matt_Drake
 Max_Hardcore
 Michael_J_Cox
 Michael_Stefano
-Mike_Feline
 Mike_Foster
 Mike_Horner
 Mike_Ranger
-Mike_South
 Mickey_G
 Miles_Malone
-Mr_Lothar
 Mr_Marcus
 Mr_Pete
+Maxo_bono
 Nacho_Vidal
 Nat_Turnher
 Nick_East
 Nick_Lang
 Nick_Manning
 Nikko_Knight
+Martinucci_Dario
 Matt_Bixel
 Neeo
-Pascal_Saint
+Pascal_Saint_James
 Pat_Myne
+Fabian
 Paul_Barresi
 Paul_Cox
 Paul_Thomas
@@ -1118,6 +896,7 @@ Peter_Foster
 Peter_Ho
 Peter_North
 Peter_Shaft
+Phatzane
 Philippe_Dean
 Philippe_Soine
 Pier_Evergreen
@@ -1126,15 +905,11 @@ Preston_Parker
 Randy_Spears
 Randy_West
 Ray_Victory
-Remigio_Zampa
 Ricardo_Bell
 Richard_Langin
 Rich_Handsome
 Rick_Masters
-Rick_Lee
-Rob_Rotten
 Robbie_James
-Robert_Darcy
 Robert_Rosenberg
 Roberto_Malone
 Rod_Danger
@@ -1145,10 +920,8 @@ Rocco_Siffredi
 Rod_Fontana
 Ron_Jeremy
 Ryan_Idol
-Richard_Pacheco
 Samson_Biceps
 Sam_Strong
-Sascha
 Scott_Lyons
 Scott_Styles
 Sean_Michaels
@@ -1160,8 +933,8 @@ Silvio_Evangelista
 Simon_Rex
 Skunk_Riley
 Sledge_Hammer
-Spyder_Jonez
 Stephen_Wolfe
+Sparky_O_Toole
 Steve_Holmes
 Steve_Hooper
 Steve_York
@@ -1170,12 +943,11 @@ Steven_St_Croix
 T_J_Cummings
 TT_Boy
 Tom_Byron
-Tom_Cruiso
 Tony_DeSergio
 Tony_Everready
 Tony_Martino
 Tony_Michaels
-Toni_Ribas
+Tony_Ribas
 Tony_Tedeschi
 Tony_Sexton
 Trent_Tesoro
@@ -1183,23 +955,15 @@ Trevor_Zen
 Tyce_Bune
 Tyler_Knight
 Ty_Lattimore
-Tom_Shepard
 Valentino_Rey
 Van_Damage
 Van_Darkholme
 Vince_Vouyer
 Voodoo
-Walter_Midolo
-Wes_Bauer
 Wesley_Pipes
 Will_Ravage
-Willi_Montana
-Willy_Braque
 Wilde_Oscar
 Woody_Long
 Yoshiya_Minami
-Yves_Baillat
-Yves_Callas
 Zake_Thomas
 Zensa_Raggi
-Zare_Prejaki
